@@ -118,6 +118,9 @@ class RawHid(DevConnBase):
             self.dev.Write = type(self.dev.Write) (Win32Write, self.dev)
             self.dev.Read = type(self.dev.Read ) (Win32Read, self.dev)
 
+        if sys.platform.startswith('linux'):
+            self.dev.Write = type(self.dev.Write) (LinuxWrite, self.dev)
+
     def close(self):
         """ close the interface """
 
@@ -220,3 +223,8 @@ def Win32Read(self):
     # Convert the string buffer to a list of numbers.  Throw away the first
     # byte, which is the report id (which we don't care about).
     return b''.join(buf)
+
+def LinuxWrite(self, packet):
+    """See base class."""
+    out = bytes(bytearray(packet))  # DO NOT Prepend the zero-byte (report ID)
+    os.write(self.dev, out)
